@@ -167,4 +167,5 @@ class Controller(rest.RestController):
         #       the request object to make the links.
         return V1.convert()
 
-__all__ = (Controller)
+
+__all__ = ("Controller", )
